@@ -1,5 +1,6 @@
 #' @title Percent area sample
-#' @description Creates a point sample of polygons where n is based on percent area
+#' @description Creates a point sample of polygons where n is based 
+#'              on percent area
 #'
 #' @param x sp SpatialPolygonsDataFrame object
 #' @param pct Percent of area sampled
@@ -9,7 +10,8 @@
 #' @param stype Sampling type ('random', 'regular', 'nonaligned', 'hexagonal')
 #' @param ... Additional arguments passed to spsample
 #'
-#' @note This function results in an adaptive sample based on the area of each polygon
+#' @note This function results in an adaptive sample based on the area of 
+#'       each polygon
 #'
 #' @return A SpatialPointsDataFrame with polygon samples
 #'
@@ -17,12 +19,12 @@
 #'
 #' @examples 
 #' require(sp)
-#' sr1=Polygons(list(Polygon(cbind(c(180114, 180553, 181127, 181477, 181294, 181007, 180409, 
-#'   180162, 180114), c(332349, 332057, 332342, 333250, 333558, 333676, 
-#'   332618, 332413, 332349)))),'1')
-#' sr2=Polygons(list(Polygon(cbind(c(180042, 180545, 180553, 180314, 179955, 179142, 179437, 
-#'   179524, 179979, 180042), c(332373, 332026, 331426, 330889, 330683, 
-#'   331133, 331623, 332152, 332357, 332373)))),'2')
+#' sr1=Polygons(list(Polygon(cbind(c(180114, 180553, 181127, 181477, 181294, 
+#'   181007, 180409, 180162, 180114), c(332349, 332057, 332342, 333250, 333558, 
+#'   333676, 332618, 332413, 332349)))),'1')
+#' sr2=Polygons(list(Polygon(cbind(c(180042, 180545, 180553, 180314, 179955, 
+#'   179142, 179437, 179524, 179979, 180042), c(332373, 332026, 331426, 330889, 
+#'   330683, 331133, 331623, 332152, 332357, 332373)))),'2')
 #' sr=SpatialPolygons(list(sr1,sr2))
 #' srdf=SpatialPolygonsDataFrame(sr, data.frame(row.names=c('1','2'), PIDS=1:2))
 #' 
@@ -45,8 +47,9 @@ parea.sample <- function(x, pct = 0.1, join = FALSE, msamp = 1, sf = 4046.86,
         if (ns < msamp) { ns <- msamp }
           psamp <- try( sp::spsample(psub, n = ns, type = stype, iter = 10, ...) )
 		  if(class(psamp) != "try-error") {
-            samp.list[[i]] <- sp::SpatialPointsDataFrame(psamp, data = data.frame(ID = rep(as.numeric(pids[i]), 
-	  	                                        dim(sp::coordinates(psamp))[1])))
+            samp.list[[i]] <- sp::SpatialPointsDataFrame(psamp, 
+			  data = data.frame(ID = rep(as.numeric(pids[i]), 
+	  	      dim(sp::coordinates(psamp))[1])))
 		  } else {
 		    samp.list[[i]] <- NULL
           }			
