@@ -9,17 +9,17 @@
 #' data.frame, nrow(x) and ncol of function results
 #'
 #' @note
-#' This function calculates the zonal statistics between a polygon vector object and a raster. 
-#'   This provides the advantage of being able to accept any custom function, passed to the 'stats' 
-#    argument. Please note that any custom function needs to have a 'na.rm' argument.     
-#'
-#' @note Depends: sp, raster, velox
+#' This function calculates the zonal statistics between a polygon vector 
+#' object and a raster. This provides the advantage of being able to accept 
+#' any custom function, passed to the 'stats' argument. Please note that 
+#' any custom function needs to have a 'na.rm' argument.     
 #'
 #' @author Jeffrey S. Evans  <jeffrey_evans@@tnc.org>
 #'
 #' @examples
 #' library(raster)
 #' library(sp)                                                                          
+#'
 #' # skewness function
 #' skew <- function(x, na.rm = FALSE) { 
 #'    if (na.rm) 
@@ -49,17 +49,18 @@
 #'   ( z <- data.frame(ID = as.numeric(as.character(row.names(p@@data))), 
 #'                     SKEW=z.skew, PCT=z.pct) )  
 #'
-#' @import velox
-#' @export
+#' @export zonal.stats
 zonal.stats <- function(x, y, stats = c("min", "mean", "max")) {
-  # if(class(x) == "sf") { x <- as(x, "Spatial") }
-    if (class(y) != "RasterLayer" & class(y) != "RasterStack" & class(y) != "RasterBrick") 
-        stop("y must be a raster (layer, stack, brick) class object")
-    if (class(x) != "SpatialPolygonsDataFrame") 
-        stop("x must be a SpatialPolygonsDataFrame object")
-    rvx <- velox::velox(y) 
-      ldf <- rvx$extract(sp = x)
-	    names(ldf) <- row.names(x)	  
+    if (!any(class(y)[1] == c("RasterLayer", "RasterStack", "RasterBrick"))) 
+      stop("y must be a raster (layer, stack, brick) class object")
+    if (!any(class(x)[1] == c("SpatialPolygonsDataFrame", "sf"))) 
+      stop("x must be a SpatialPolygonsDataFrame or sf POLYGON object")
+    if(inherits(x, "SpatialPolygonsDataFrame")) {
+	  x <- sf::st_as_sf(x)
+	}  
+    ldf <- exactextractr::exact_extract(y, x, progress = FALSE)
+	  names(ldf) <- row.names(x)
+    ldf <- lapply(ldf, FUN = function(x) as.data.frame(x[,-which(names(x) %in% "coverage_fraction")]))
     stats.fun <- function(x, m = stats) {
 	  slist <- list()
         for(i in 1:length(m)) {
